==> v0.6.0.zip: elasticsearch/modules/elasticsearch/src/main/java/org/elasticsearch/indices/InternalIndicesLifecycle.java <==
/*
 * Licensed to Elastic Search and Shay Banon under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. Elastic Search licenses this
 * file to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.elasticsearch.indices;

import com.google.inject.Inject;
import org.elasticsearch.index.Index;
import org.elasticsearch.index.service.IndexService;
import org.elasticsearch.index.shard.ShardId;
import org.elasticsearch.index.shard.service.IndexShard;
import org.elasticsearch.util.component.AbstractComponent;
import org.elasticsearch.util.settings.Settings;

import java.util.concurrent.CopyOnWriteArrayList;

/**
 * @author kimchy (shay.banon)
 */
public class InternalIndicesLifecycle extends AbstractComponent implements IndicesLifecycle {

    private final CopyOnWriteArrayList<Listener> listeners = new CopyOnWriteArrayList<Listener>();

    @Inject public InternalIndicesLifecycle(Settings settings) {
        super(settings);
    }

    public void addListener(Listener listener) {
        listeners.add(listener);
    }

    public void removeListener(Listener listener) {
        listeners.remove(listener);
    }

    public void beforeIndexCreated(Index index) {
        for (Listener listener : listeners) {
            listener.beforeIndexCreated(index);
        }
    }

    public void afterIndexCreated(IndexService indexService) {
        for (Listener listener : listeners) {
            listener.afterIndexCreated(indexService);
        }
    }

    public void beforeIndexShardCreated(ShardId shardId) {
        for (Listener listener : listeners) {
            listener.beforeIndexShardCreated(shardId);
        }
    }

    public void afterIndexShardCreated(IndexShard indexShard) {
        for (Listener listener : listeners) {
            listener.afterIndexShardCreated(indexShard);
        }
    }

    public void beforeIndexClosed(IndexService indexService, boolean delete) {
        for (Listener listener : listeners) {
            listener.beforeIndexClosed(indexService, delete);
        }
    }

    public void afterIndexClosed(Index index, boolean delete) {
        for (Listener listener : listeners) {
            listener.afterIndexClosed(index, delete);
        }
    }

    public void beforeIndexShardClosed(IndexShard indexShard, boolean delete) {
        for (Listener listener : listeners) {
            listener.beforeIndexShardClosed(indexShard, delete);
        }
    }

    public void afterIndexShardClosed(ShardId shardId, boolean delete) {
        for (Listener listener : listeners) {
            listener.afterIndexShardClosed(shardId, delete);
        }
    }
}

==> v0.7.0.zip: elasticsearch/modules/elasticsearch/src/main/java/org/elasticsearch/indices/InternalIndicesLifecycle.java <==
/*
 * Licensed to Elastic Search and Shay Banon under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. Elastic Search licenses this
 * file to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.elasticsearch.indices;

import org.elasticsearch.util.inject.Inject;
import org.elasticsearch.index.Index;
import org.elasticsearch.index.service.IndexService;
import org.elasticsearch.index.shard.ShardId;
import org.elasticsearch.index.shard.service.IndexShard;
import org.elasticsearch.util.component.AbstractComponent;
import org.elasticsearch.util.settings.Settings;

import java.util.concurrent.CopyOnWriteArrayList;

/**
 * @author kimchy (shay.banon)
 */
public class InternalIndicesLifecycle extends AbstractComponent implements IndicesLifecycle {

    private final CopyOnWriteArrayList<Listener> listeners = new CopyOnWriteArrayList<Listener>();

    @Inject public InternalIndicesLifecycle(Settings settings) {
        super(settings);
    }

    public void addListener(Listener listener) {
        listeners.add(listener);
    }

    public void removeListener(Listener listener) {
        listeners.remove(listener);
    }

    public void beforeIndexCreated(Index index) {
        for (Listener listener : listeners) {
            listener.beforeIndexCreated(index);
        }
    }

    public void afterIndexCreated(IndexService indexService) {
        for (Listener listener : listeners) {
            listener.afterIndexCreated(indexService);
        }
    }

    public void beforeIndexShardCreated(ShardId shardId) {
        for (Listener listener : listeners) {
            listener.beforeIndexShardCreated(shardId);
        }
    }

    public void afterIndexShardCreated(IndexShard indexShard) {
        for (Listener listener : listeners) {
            listener.afterIndexShardCreated(indexShard);
        }
    }

    public void beforeIndexClosed(IndexService indexService, boolean delete) {
        for (Listener listener : listeners) {
            listener.beforeIndexClosed(indexService, delete);
        }
    }

    public void afterIndexClosed(Index index, boolean delete) {
        for (Listener listener : listeners) {
            listener.afterIndexClosed(index, delete);
        }
    }

    public void beforeIndexShardClosed(IndexShard indexShard, boolean delete) {
        for (Listener listener : listeners) {
            listener.beforeIndexShardClosed(indexShard, delete);
        }
    }

    public void afterIndexShardClosed(ShardId shardId, boolean delete) {
        for (Listener listener : listeners) {
            listener.afterIndexShardClosed(shardId, delete);
        }
    }
}
